Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
safe-sid
Safe wrapper for working with SIDs from the Windows API.
Provides the borrowed/owned pair &Sid and SidBuf along with safe helper functions. Byte-compatible with the Windows SID struct. Defines equality and ordering traits so they can be compared and keyed on.
Depends on the windows crate by default, but this can be reduced down to just windows-core by turning off default features.
Usage
[]
= "0.1"
Or for just the windows-core dependency:
[]
= { = "0.1", = false }
Build a SID by hand
let admins = new.unwrap;
assert_eq!;
Build a well-known SID
let local_system = well_known.unwrap;
assert_eq!;
Pass a SID to a Windows API
// Just an example, use Sid::to_string() normally
Fill a SidBuf from a Windows API
Sometimes a SID comes from a Windows API that expects the caller to provide a buffer. You can unsafely acquire a mutable pointer, and are responsible for ensuring it is filled with a valid SID with a correctly matching length.
Note that even if the SID is malformed, dropping SidBuf will still be safe.
License
Licensed under the ISC License.